.. include:: links.inc

.. image:: images/junifer_logo.png
   :width: 300px
   :alt: junifer logo

Welcome to junifer's documentation!
===================================

junifer (JUelich NeuroImaging FEature extractoR) is a data handling and feature
extraction library targeted towards neuroimaging data specifically functional
MRI data.

It is curently being developed and maintained at the Applied Machine Learning
(`AML`_) group at Forschungszentrum Juelich, Germany. Although the library is
designed for people working at Institute of Neuroscience and Medicine - Brain
and Behaviour (`INM-7`_), it is designed to be as modular as possible thus
enabling others to extend it easily.

.. toctree::
   :numbered: 3
   :maxdepth: 2
   :caption: Contents:

   installation
   understanding/index.rst
   using/index.rst
   builtin
   extending/index.rst
   auto_examples/index.rst
   api/index.rst
   contribution
   maintaining
   faq
   whats_new


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
